@@ -1,6 +1,6 @@
 /*
  *   stunnel       TLS offloading and load-balancing proxy
- *   Copyright (C) 1998-2016 Michal Trojnara <Michal.Trojnara@mirt.net>
+ *   Copyright (C) 1998-2016 Michal Trojnara <Michal.Trojnara@stunnel.org>
  *
  *   This program is free software; you can redistribute it and/or modify it
  *   under the terms of the GNU General Public License as published by the
@@ -183,10 +183,10 @@ NOEXPORT void cron_dh_param(void) {
 #endif
 
     /* update global dh_params for future configuration reloads */
-    CRYPTO_w_lock(stunnel_locks[LOCK_DH]);
+    CRYPTO_THREAD_write_lock(stunnel_locks[LOCK_DH]);
     DH_free(dh_params);
     dh_params=dh;
-    CRYPTO_w_unlock(stunnel_locks[LOCK_DH]);
+    CRYPTO_THREAD_write_unlock(stunnel_locks[LOCK_DH]);
 
     /* set for all sections that require it */
     for(opt=service_options.next; opt; opt=opt->next)
